@@ -40,7 +40,7 @@
 #include <lib/rb-util.h>
 
 /**
- * SECTION:rb-ext-db
+ * SECTION:rbextdb
  * @short_description: store for external metadata such as album art
  *
  * This class simplifies searching for and providing external metadata
@@ -83,6 +83,7 @@ struct _RBExtDBPrivate
 	struct tdb_context *tdb_context;
 
 	GList *requests;
+	GList *load_requests;
 	GAsyncQueue *store_queue;
 	GSimpleAsyncResult *store_op;
 };
@@ -548,7 +549,11 @@ lookup_cb (TDB_DATA data, RBExtDBKey *key, gpointer user_data)
 
 	tdbvalue = tdb_fetch (lookup->store->priv->tdb_context, data);
 	if (tdbvalue.dptr == NULL) {
-		rb_debug ("lookup failed");
+		if (rb_debug_here ()) {
+			char *str = rb_ext_db_key_to_string (key);
+			rb_debug ("lookup for key %s failed", str);
+			g_free (str);
+		}
 		return TRUE;
 	}
 
@@ -622,8 +627,10 @@ load_request_cb (RBExtDB *store, GAsyncResult *result, gpointer data)
 	req = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result));
 
 	rb_debug ("finished loading %s", req->filename);
-	req->callback (req->key, req->store_key, req->filename, req->data, req->user_data);
+	if (req->callback)
+		req->callback (req->key, req->store_key, req->filename, req->data, req->user_data);
 
+	store->priv->load_requests = g_list_remove (store->priv->load_requests, req);
 	g_object_unref (result);
 }
 
@@ -647,17 +654,16 @@ do_load_request (GSimpleAsyncResult *result, GObject *object, GCancellable *canc
 
 		/* probably need to delete the item from the db */
 	} else {
-		GString *s;
+		GBytes *b;
 		GValue d = G_VALUE_INIT;
 
 		/* convert the encoded data into a useful object */
 		rb_debug ("converting %" G_GSIZE_FORMAT " bytes of file data", file_data_size);
-		s = g_slice_new0 (GString);
-		s->str = file_data;
-		s->len = file_data_size;
-		s->allocated_len = file_data_size;
-		g_value_init (&d, G_TYPE_GSTRING);
-		g_value_take_boxed (&d, s);
+
+		b = g_bytes_new_take (file_data, file_data_size);
+		g_value_init (&d, G_TYPE_BYTES);
+		g_value_take_boxed (&d, b);
+
 		req->data = NULL;
 		g_signal_emit (object, signals[LOAD], 0, &d, &req->data);
 		g_value_unset (&d);
@@ -702,6 +708,7 @@ rb_ext_db_request (RBExtDB *store,
 	char *filename;
 	GList *l;
 	gboolean emit_request = TRUE;
+	gboolean add_request = TRUE;
 	RBExtDBKey *store_key = NULL;
 
 	rb_debug ("starting metadata request");
@@ -720,29 +727,34 @@ rb_ext_db_request (RBExtDB *store,
 			if (destroy)
 				destroy (user_data);
 			rb_ext_db_key_free (store_key);
+		} else {
+			if (rb_debug_here ()) {
+				char *str = rb_ext_db_key_to_string (store_key);
+				rb_debug ("found cached match %s under key %s", filename, str);
+				g_free (str);
+			}
+			load_op = g_simple_async_result_new (G_OBJECT (store),
+							     (GAsyncReadyCallback) load_request_cb,
+							     NULL,
+							     rb_ext_db_request);
+
+			req = create_request (key, callback, user_data, destroy);
+			req->filename = filename;
+			req->store_key = store_key;
+			g_simple_async_result_set_op_res_gpointer (load_op, req, (GDestroyNotify) free_request);
+			store->priv->load_requests = g_list_append (store->priv->load_requests, req);
+
+			g_simple_async_result_run_in_thread (load_op,
+							     do_load_request,
+							     G_PRIORITY_DEFAULT,
+							     NULL);	/* no cancel? */
+		}
+
+		if (rb_ext_db_key_is_null_match (key, store_key) == FALSE)
 			return FALSE;
-		}
 
-		if (rb_debug_here ()) {
-			char *str = rb_ext_db_key_to_string (store_key);
-			rb_debug ("found cached match %s under key %s", filename, str);
-			g_free (str);
-		}
-		load_op = g_simple_async_result_new (G_OBJECT (store),
-						     (GAsyncReadyCallback) load_request_cb,
-						     NULL,
-						     rb_ext_db_request);
-
-		req = create_request (key, callback, user_data, destroy);
-		req->filename = filename;
-		req->store_key = store_key;
-		g_simple_async_result_set_op_res_gpointer (load_op, req, (GDestroyNotify) free_request);
-
-		g_simple_async_result_run_in_thread (load_op,
-						     do_load_request,
-						     G_PRIORITY_DEFAULT,
-						     NULL);	/* no cancel? */
-		return FALSE;
+		rb_debug ("found null match, continuing to issue requests");
+		add_request = FALSE;
 	}
 
 	/* discard duplicate requests, combine equivalent requests */
@@ -776,9 +788,11 @@ rb_ext_db_request (RBExtDB *store,
 	}
 	g_free (tdbkey.dptr);
 
-	/* add stuff to list of outstanding requests */
-	req = create_request (key, callback, user_data, destroy);
-	store->priv->requests = g_list_append (store->priv->requests, req);
+	if (add_request) {
+		/* add stuff to list of outstanding requests */
+		req = create_request (key, callback, user_data, destroy);
+		store->priv->requests = g_list_append (store->priv->requests, req);
+	}
 
 	/* and let metadata providers request it */
 	if (emit_request) {
@@ -788,10 +802,59 @@ rb_ext_db_request (RBExtDB *store,
 		result = TRUE;
 	}
 
-	/* free the request if result == FALSE? */
 	return result;
 }
 
+/**
+ * rb_ext_db_cancel_requests:
+ * @store: metadata store instance
+ * @callback: callback function
+ * @user_data: user data
+ *
+ * Cancels all outstanding requests matching the specified callback and user data.
+ * In cases where the user data for a request is an object, this should be called
+ * early in object's dispose function to ensure that the callback is not called
+ * on a partly or fully disposed object.
+ */
+void
+rb_ext_db_cancel_requests (RBExtDB *store, RBExtDBRequestCallback callback, gpointer user_data)
+{
+	GList *l;
+
+	l = store->priv->requests;
+	while (l != NULL) {
+		RBExtDBRequest *req = l->data;
+		if (req->callback == callback && req->user_data == user_data) {
+			GList *n = l->next;
+			char *str = rb_ext_db_key_to_string (req->key);
+			rb_debug ("cancelling a search request: %s", str);
+			g_free (str);
+			free_request (req);
+			store->priv->requests = g_list_delete_link (store->priv->requests, l);
+			l = n;
+		} else {
+			l = l->next;
+		}
+	}
+
+	l = store->priv->load_requests;
+	while (l != NULL) {
+		RBExtDBRequest *req = l->data;
+		if (req->callback == callback && req->user_data == user_data) {
+			char *str = rb_ext_db_key_to_string (req->key);
+			rb_debug ("cancelling a load request: %s", str);
+			g_free (str);
+			if (req->destroy_notify)
+				req->destroy_notify (req->user_data);
+			req->callback = NULL;
+			req->user_data = NULL;
+			req->destroy_notify = NULL;
+		} else {
+			l = l->next;
+		}
+	}
+}
+
 static void
 delete_file (RBExtDB *store, const char *filename)
 {
@@ -925,12 +988,12 @@ do_store_request (GSimpleAsyncResult *result, GObject *object, GCancellable *can
 			g_clear_error (&error);
 			/* leave req->data alone so we fall into the failure branch? */
 		} else {
-			GString *s;
+			GBytes *b;
 			rb_debug ("got %" G_GSIZE_FORMAT " bytes from uri %s", data_size, req->uri);
-			s = g_string_new_len (data, data_size);
+			b = g_bytes_new_take (data, data_size);
 			req->data = g_new0 (GValue, 1);
-			g_value_init (req->data, G_TYPE_GSTRING);
-			g_value_take_boxed (req->data, s);
+			g_value_init (req->data, G_TYPE_BYTES);
+			g_value_take_boxed (req->data, b);
 		}
 
 		g_object_unref (f);
