@@ -45,10 +45,10 @@
 #define TOP_TRACKS_LIFETIME 86400            /* 24 hours */
 #define LOVED_TRACKS_LIFETIME 86400          /* 24 hours */
 #define TOP_ARTISTS_LIFETIME 86400           /* 24 hours */
-#define RECOMMENDED_ARTISTS_LIFETIME 86400   /* 24 hours */
 
 static RBAudioscrobblerUserData *
-rb_audioscrobbler_user_data_new () {
+rb_audioscrobbler_user_data_new (void)
+{
 	RBAudioscrobblerUserData *data = g_slice_new0 (RBAudioscrobblerUserData);
 
 	data->refcount = 1;
@@ -128,7 +128,6 @@ struct _RBAudioscrobblerUserPrivate {
 	GPtrArray *top_tracks;
 	GPtrArray *loved_tracks;
 	GPtrArray *top_artists;
-	GPtrArray *recommended_artists;
 
 	/* for image downloads */
 	GHashTable *file_to_data_queue_map;
@@ -166,51 +165,43 @@ static GPtrArray * parse_artist_array (RBAudioscrobblerUser *user, JsonArray *tr
 static void load_cached_user_info (RBAudioscrobblerUser *user);
 static void request_user_info (RBAudioscrobblerUser *user);
 static void user_info_response_cb (SoupSession *session,
-                                   SoupMessage *msg,
-                                   gpointer user_data);
+                                   GAsyncResult *result,
+				   RBAudioscrobblerUser *user);
 static RBAudioscrobblerUserData * parse_user_info (RBAudioscrobblerUser *user,
                                                    const char *data);
 
 static void load_cached_recent_tracks (RBAudioscrobblerUser *user);
 static void request_recent_tracks (RBAudioscrobblerUser *user, int limit);
 static void recent_tracks_response_cb (SoupSession *session,
-                                       SoupMessage *msg,
-                                       gpointer user_data);
+                                       GAsyncResult *result,
+                                       RBAudioscrobblerUser *user);
 static GPtrArray * parse_recent_tracks (RBAudioscrobblerUser *user,
                                         const char *data);
 
 static void load_cached_top_tracks (RBAudioscrobblerUser *user);
 static void request_top_tracks (RBAudioscrobblerUser *user, int limit);
 static void top_tracks_response_cb (SoupSession *session,
-                                    SoupMessage *msg,
-                                    gpointer user_data);
+                                    GAsyncResult *result,
+				    RBAudioscrobblerUser *user);
 static GPtrArray * parse_top_tracks (RBAudioscrobblerUser *user,
                                      const char *data);
 
 static void load_cached_loved_tracks (RBAudioscrobblerUser *user);
 static void request_loved_tracks (RBAudioscrobblerUser *user, int limit);
 static void loved_tracks_response_cb (SoupSession *session,
-                                      SoupMessage *msg,
-                                      gpointer user_data);
+                                      GAsyncResult *result,
+				      RBAudioscrobblerUser *user);
 static GPtrArray * parse_loved_tracks (RBAudioscrobblerUser *user,
                                        const char *data);
 
 static void load_cached_top_artists (RBAudioscrobblerUser *user);
 static void request_top_artists (RBAudioscrobblerUser *user, int limit);
 static void top_artists_response_cb (SoupSession *session,
-                                     SoupMessage *msg,
-                                     gpointer user_data);
+                                     GAsyncResult *result,
+				     RBAudioscrobblerUser *user);
 static GPtrArray * parse_top_artists (RBAudioscrobblerUser *user,
                                       const char *data);
 
-static void load_cached_recommended_artists (RBAudioscrobblerUser *user);
-static void request_recommended_artists (RBAudioscrobblerUser *user, int limit);
-static void recommended_artists_response_cb (SoupSession *session,
-                                             SoupMessage *msg,
-                                             gpointer user_data);
-static GPtrArray * parse_recommended_artists (RBAudioscrobblerUser *user,
-                                              const char *data);
-
 static char * calculate_cached_image_path (RBAudioscrobblerUser *user,
                                            RBAudioscrobblerUserData *data);
 static void download_image (RBAudioscrobblerUser *user,
@@ -219,13 +210,13 @@ static void download_image (RBAudioscrobblerUser *user,
 static void image_download_cb (GObject *source_object,
                                GAsyncResult *res,
                                gpointer user_data);
-
 static void love_track_response_cb (SoupSession *session,
-                                    SoupMessage *msg,
-                                    gpointer user_data);
+                                    GAsyncResult *result,
+                                    RBAudioscrobblerUser *user);
 static void ban_track_response_cb (SoupSession *session,
-                                   SoupMessage *msg,
-                                   gpointer user_data);
+                                   GAsyncResult *result,
+                                   RBAudioscrobblerUser *user);
+
 enum {
 	PROP_0,
 	PROP_SERVICE
@@ -237,7 +228,6 @@ enum {
 	TOP_TRACKS_UPDATED,
 	LOVED_TRACKS_UPDATED,
 	TOP_ARTISTS_UPDATED,
-	RECOMMENDED_ARTISTS_UPDATED,
 	LAST_SIGNAL
 };
 
@@ -328,17 +318,6 @@ rb_audioscrobbler_user_class_init (RBAudioscrobblerUserClass *klass)
 		              1,
 		              G_TYPE_PTR_ARRAY);
 
-	rb_audioscrobbler_user_signals[RECOMMENDED_ARTISTS_UPDATED] =
-		g_signal_new ("recommended-artists-updated",
-		              G_OBJECT_CLASS_TYPE (object_class),
-		              G_SIGNAL_RUN_LAST,
-		              0,
-		              NULL, NULL,
-		              NULL,
-		              G_TYPE_NONE,
-		              1,
-		              G_TYPE_PTR_ARRAY);
-
 	g_type_class_add_private (klass, sizeof (RBAudioscrobblerUserPrivate));
 }
 
@@ -352,11 +331,7 @@ rb_audioscrobbler_user_init (RBAudioscrobblerUser *user)
 {
 	user->priv = RB_AUDIOSCROBBLER_USER_GET_PRIVATE (user);
 
-	user->priv->soup_session =
-		soup_session_new_with_options (SOUP_SESSION_ADD_FEATURE_BY_TYPE,
-					       SOUP_TYPE_PROXY_RESOLVER_DEFAULT,
-					       NULL);
-
+	user->priv->soup_session = soup_session_new ();
 	user->priv->file_to_data_queue_map = g_hash_table_new_full (g_file_hash,
 	                                                            (GEqualFunc) g_file_equal,
 	                                                            g_object_unref,
@@ -413,11 +388,6 @@ rb_audioscrobbler_user_dispose (GObject* object)
 		user->priv->top_artists = NULL;
 	}
 
-	if (user->priv->recommended_artists != NULL) {
-		g_ptr_array_unref (user->priv->recommended_artists);
-		user->priv->recommended_artists = NULL;
-	}
-
 	/* free this map first because file_to_data_queue_map owns the file reference */
 	if (user->priv->file_to_cancellable_map != NULL) {
 		GList *key;
@@ -536,14 +506,6 @@ rb_audioscrobbler_user_update (RBAudioscrobblerUser *user)
 		} else {
 			rb_debug ("cached top artists is still valid, not updating");
 		}
-
-		if (is_cached_response_expired (user, "recommended_artists", RECOMMENDED_ARTISTS_LIFETIME)) {
-			rb_debug ("cached recommended artists response is expired, updating");
-			request_recommended_artists (user, 15);
-		} else {
-			rb_debug ("cached recommended artists response is still valid, not updating");
-		}
-
 	}
 }
 
@@ -557,7 +519,6 @@ rb_audioscrobbler_user_force_update (RBAudioscrobblerUser *user)
 		request_top_tracks (user, 15);
 		request_loved_tracks (user, 15);
 		request_top_artists (user, 15);
-		request_recommended_artists (user, 15);
 	}
 }
 
@@ -590,11 +551,6 @@ load_from_cache (RBAudioscrobblerUser *user)
 		user->priv->top_artists = NULL;
 	}
 
-	if (user->priv->recommended_artists != NULL) {
-		g_ptr_array_unref (user->priv->recommended_artists);
-		user->priv->recommended_artists = NULL;
-	}
-
 	/* if a username is set then attempt to load cached data */
 	if (user->priv->username != NULL) {
 		load_cached_user_info (user);
@@ -602,7 +558,6 @@ load_from_cache (RBAudioscrobblerUser *user)
 		load_cached_top_tracks (user);
 		load_cached_loved_tracks (user);
 		load_cached_top_artists (user);
-		load_cached_recommended_artists (user);
 	}
 }
 
@@ -681,7 +636,6 @@ save_response_to_cache (RBAudioscrobblerUser *user, const char *request_name, co
 	g_free (file_uri);
 }
 
-/* general parsing functions (to be used by parse_recent_tracks, parse_recommended artists etc */
 static GPtrArray *
 parse_track_array (RBAudioscrobblerUser *user, JsonArray *track_array)
 {
@@ -808,50 +762,66 @@ load_cached_user_info (RBAudioscrobblerUser *user)
 static void
 request_user_info (RBAudioscrobblerUser *user)
 {
-	char *msg_url;
+	const char *api_key;
+	const char *api_url;
+	char *query;
 	SoupMessage *msg;
 
 	rb_debug ("requesting user info");
 
-	msg_url = g_strdup_printf ("%s?method=user.getInfo&user=%s&api_key=%s&format=json",
-	                           rb_audioscrobbler_service_get_api_url (user->priv->service),
-	                           user->priv->username,
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service));
+	api_key = rb_audioscrobbler_service_get_api_key (user->priv->service);
+	api_url = rb_audioscrobbler_service_get_api_url (user->priv->service);
 
-	msg = soup_message_new ("GET", msg_url);
-	soup_session_queue_message (user->priv->soup_session,
-	                            msg,
-	                            user_info_response_cb,
-	                            user);
+	query = soup_form_encode ("method", "user.getInfo",
+				  "user", user->priv->username,
+				  "api_key", api_key,
+				  "format", "json",
+				  NULL);
 
-	g_free (msg_url);
+	msg = soup_message_new_from_encoded_form (SOUP_METHOD_GET, api_url, query);
+	g_return_if_fail (msg != NULL);
+
+	soup_session_send_and_read_async (user->priv->soup_session,
+					  msg,
+					  G_PRIORITY_DEFAULT,
+					  NULL,
+					  (GAsyncReadyCallback) user_info_response_cb,
+					  user);
 }
 
 static void
 user_info_response_cb (SoupSession *session,
-                       SoupMessage *msg,
-                       gpointer user_data)
+                       GAsyncResult *result,
+                       RBAudioscrobblerUser *user)
 {
-	RBAudioscrobblerUser *user;
+	GBytes *bytes;
+	const char *body;
 	RBAudioscrobblerUserData *user_info;
 
-	user = RB_AUDIOSCROBBLER_USER (user_data);
-	user_info = parse_user_info (user, msg->response_body->data);
+	bytes = soup_session_send_and_read_finish (session, result, NULL);
+	if (bytes != NULL) {
+		body = g_bytes_get_data (bytes, NULL);
+		user_info = parse_user_info (user, body);
 
-	if (user_info != NULL) {
-		rb_debug ("user info request was successful");
+		if (user_info != NULL) {
+			rb_debug ("user info request was successful");
 
-		if (user->priv->user_info != NULL) {
-			rb_audioscrobbler_user_data_unref (user->priv->user_info);
+			if (user->priv->user_info != NULL) {
+				rb_audioscrobbler_user_data_unref (user->priv->user_info);
+			}
+			user->priv->user_info = user_info;
+
+			save_response_to_cache (user, "user_info", body);
+
+			g_signal_emit (user, rb_audioscrobbler_user_signals[USER_INFO_UPDATED],
+			               0, user->priv->user_info);
+		} else {
+			rb_debug ("invalid response from user info request");
 		}
-		user->priv->user_info = user_info;
 
-		save_response_to_cache (user, "user_info", msg->response_body->data);
-
-		g_signal_emit (user, rb_audioscrobbler_user_signals[USER_INFO_UPDATED],
-		               0, user->priv->user_info);
+		g_bytes_unref (bytes);
 	} else {
-		rb_debug ("invalid response from user info request");
+		rb_debug ("error sending user info request");
 	}
 }
 
@@ -936,51 +906,72 @@ load_cached_recent_tracks (RBAudioscrobblerUser *user)
 static void
 request_recent_tracks (RBAudioscrobblerUser *user, int limit)
 {
-	char *msg_url;
+	const char *api_key;
+	const char *api_url;
+	char *limit_str;
+	char *query;
 	SoupMessage *msg;
 
 	rb_debug ("requesting recent tracks");
 
-	msg_url = g_strdup_printf ("%s?method=user.getRecentTracks&user=%s&api_key=%s&limit=%i&format=json",
-	                           rb_audioscrobbler_service_get_api_url (user->priv->service),
-	                           user->priv->username,
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
-	                           limit);
+	api_key = rb_audioscrobbler_service_get_api_key (user->priv->service);
+	api_url = rb_audioscrobbler_service_get_api_url (user->priv->service);
 
-	msg = soup_message_new ("GET", msg_url);
-	soup_session_queue_message (user->priv->soup_session,
-	                            msg,
-	                            recent_tracks_response_cb,
-	                            user);
+	limit_str = g_strdup_printf ("%d", limit);
 
-	g_free (msg_url);
+	query = soup_form_encode ("method", "user.getRecentTracks",
+				  "user", user->priv->username,
+				  "api_key", api_key,
+				  "limit", limit_str,
+				  "format", "json",
+				  NULL);
+
+	g_free (limit_str);
+
+	msg = soup_message_new_from_encoded_form (SOUP_METHOD_GET, api_url, query);
+	g_return_if_fail (msg != NULL);
+
+	soup_session_send_and_read_async (user->priv->soup_session,
+					  msg,
+					  G_PRIORITY_DEFAULT,
+					  NULL,
+					  (GAsyncReadyCallback) recent_tracks_response_cb,
+					  user);
 }
 
 static void
 recent_tracks_response_cb (SoupSession *session,
-                           SoupMessage *msg,
-                           gpointer user_data)
+                           GAsyncResult *result,
+                           RBAudioscrobblerUser *user)
 {
-	RBAudioscrobblerUser *user;
+	GBytes *bytes;
+	const char *body;
 	GPtrArray *recent_tracks;
 
-	user = RB_AUDIOSCROBBLER_USER (user_data);
-	recent_tracks = parse_recent_tracks (user, msg->response_body->data);
+	bytes = soup_session_send_and_read_finish (session, result, NULL);
+	if (bytes != NULL) {
+		body = g_bytes_get_data (bytes, NULL);
+		recent_tracks = parse_recent_tracks (user, body);
 
-	if (recent_tracks != NULL) {
-		rb_debug ("recent tracks request was successful");
+		if (recent_tracks != NULL) {
+			rb_debug ("recent tracks request was successful");
 
-		if (user->priv->recent_tracks != NULL) {
-			g_ptr_array_unref (user->priv->recent_tracks);
+			if (user->priv->recent_tracks != NULL) {
+				g_ptr_array_unref (user->priv->recent_tracks);
+			}
+			user->priv->recent_tracks = recent_tracks;
+
+			save_response_to_cache (user, "recent_tracks", body);
+
+			g_signal_emit (user, rb_audioscrobbler_user_signals[RECENT_TRACKS_UPDATED],
+			               0, user->priv->recent_tracks);
+		} else {
+			rb_debug ("invalid response from recent tracks request");
 		}
-		user->priv->recent_tracks = recent_tracks;
 
-		save_response_to_cache (user, "recent_tracks", msg->response_body->data);
-
-		g_signal_emit (user, rb_audioscrobbler_user_signals[RECENT_TRACKS_UPDATED],
-		               0, user->priv->recent_tracks);
+		g_bytes_unref (bytes);
 	} else {
-		rb_debug ("invalid response from recent tracks request");
+		rb_debug ("error sending recent tracks request");
 	}
 }
 
@@ -1051,51 +1042,71 @@ load_cached_top_tracks (RBAudioscrobblerUser *user)
 static void
 request_top_tracks (RBAudioscrobblerUser *user, int limit)
 {
-	char *msg_url;
+	const char *api_key;
+	const char *api_url;
+	char *limit_str;
+	char *query;
 	SoupMessage *msg;
 
 	rb_debug ("requesting top tracks");
 
-	msg_url = g_strdup_printf ("%s?method=library.getTracks&user=%s&api_key=%s&limit=%i&format=json",
-	                           rb_audioscrobbler_service_get_api_url (user->priv->service),
-	                           user->priv->username,
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
-	                           limit);
+	api_url = rb_audioscrobbler_service_get_api_url (user->priv->service);
+	api_key = rb_audioscrobbler_service_get_api_key (user->priv->service);
 
-	msg = soup_message_new ("GET", msg_url);
-	soup_session_queue_message (user->priv->soup_session,
-	                            msg,
-	                            top_tracks_response_cb,
-	                            user);
+	limit_str = g_strdup_printf ("%d", limit);
 
-	g_free (msg_url);
+	query = soup_form_encode ("method", "library.getTracks",
+				  "user", user->priv->username,
+				  "api_key", api_key,
+				  "limit", limit_str,
+				  "format", "json",
+				  NULL);
+	g_free (limit_str);
+
+	msg = soup_message_new_from_encoded_form (SOUP_METHOD_GET, api_url, query);
+	g_return_if_fail (msg != NULL);
+
+	soup_session_send_and_read_async (user->priv->soup_session,
+					  msg,
+					  G_PRIORITY_DEFAULT,
+					  NULL,
+					  (GAsyncReadyCallback) top_tracks_response_cb,
+					  user);
 }
 
 static void
 top_tracks_response_cb (SoupSession *session,
-                        SoupMessage *msg,
-                        gpointer user_data)
+                        GAsyncResult *result,
+			RBAudioscrobblerUser *user)
 {
-	RBAudioscrobblerUser *user;
+	GBytes *bytes;
+	const char *body;
 	GPtrArray *top_tracks;
 
-	user = RB_AUDIOSCROBBLER_USER (user_data);
-	top_tracks = parse_top_tracks (user, msg->response_body->data);
+	bytes = soup_session_send_and_read_finish (session, result, NULL);
+	if (bytes != NULL) {
+		body = g_bytes_get_data (bytes, NULL);
+		top_tracks = parse_top_tracks (user, body);
 
-	if (top_tracks != NULL) {
-		rb_debug ("top tracks request was successful");
+		if (top_tracks != NULL) {
+			rb_debug ("top tracks request was successful");
 
-		if (user->priv->top_tracks != NULL) {
-			g_ptr_array_unref (user->priv->top_tracks);
+			if (user->priv->top_tracks != NULL) {
+				g_ptr_array_unref (user->priv->top_tracks);
+			}
+			user->priv->top_tracks = top_tracks;
+
+			save_response_to_cache (user, "top_tracks", body);
+
+			g_signal_emit (user, rb_audioscrobbler_user_signals[TOP_TRACKS_UPDATED],
+				       0, user->priv->top_tracks);
+		} else {
+			rb_debug ("invalid response from top tracks request");
 		}
-		user->priv->top_tracks = top_tracks;
 
-		save_response_to_cache (user, "top_tracks", msg->response_body->data);
-
-		g_signal_emit (user, rb_audioscrobbler_user_signals[TOP_TRACKS_UPDATED],
-		               0, user->priv->top_tracks);
+		g_bytes_unref (bytes);
 	} else {
-		rb_debug ("invalid response from top tracks request");
+		rb_debug ("error sending top tracks request");
 	}
 }
 
@@ -1112,9 +1123,9 @@ parse_top_tracks (RBAudioscrobblerUser *user, const char *data)
 		JsonObject *root_object;
 		root_object = json_node_get_object (json_parser_get_root (parser));
 
-		if (json_object_has_member (root_object, "tracks")) {
+		if (json_object_has_member (root_object, "toptracks")) {
 			JsonObject *top_tracks_object;
-			top_tracks_object = json_object_get_object_member (root_object, "tracks");
+			top_tracks_object = json_object_get_object_member (root_object, "toptracks");
 
 			if (json_object_has_member (top_tracks_object, "track") == TRUE) {
 				JsonArray *track_array;
@@ -1123,7 +1134,7 @@ parse_top_tracks (RBAudioscrobblerUser *user, const char *data)
 				top_tracks = parse_track_array (user, track_array);
 			}
 		} else {
-			rb_debug ("error parsing top tracks response: no tracks object exists");
+			rb_debug ("error parsing top tracks response: no toptracks object exists");
 		}
 	} else {
 		rb_debug ("error parsing top tracks response: empty or invalid response");
@@ -1166,51 +1177,72 @@ load_cached_loved_tracks (RBAudioscrobblerUser *user)
 static void
 request_loved_tracks (RBAudioscrobblerUser *user, int limit)
 {
-	char *msg_url;
+	const char *api_key;
+	const char *api_url;
+	char *limit_str;
+	char *query;
 	SoupMessage *msg;
 
 	rb_debug ("requesting loved tracks");
 
-	msg_url = g_strdup_printf ("%s?method=user.getLovedTracks&user=%s&api_key=%s&limit=%i&format=json",
-	                           rb_audioscrobbler_service_get_api_url (user->priv->service),
-	                           user->priv->username,
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
-	                           limit);
+	api_key = rb_audioscrobbler_service_get_api_key (user->priv->service);
+	api_url = rb_audioscrobbler_service_get_api_url (user->priv->service);
 
-	msg = soup_message_new ("GET", msg_url);
-	soup_session_queue_message (user->priv->soup_session,
-	                            msg,
-	                            loved_tracks_response_cb,
-	                            user);
+	limit_str = g_strdup_printf ("%d", limit);
 
-	g_free (msg_url);
+	query = soup_form_encode ("method", "user.getLovedTracks",
+				  "user", user->priv->username,
+				  "api_key", api_key,
+				  "limit", limit_str,
+				  "format", "json",
+				  NULL);
+
+	g_free (limit_str);
+
+	msg = soup_message_new_from_encoded_form (SOUP_METHOD_GET, api_url, query);
+	g_return_if_fail (msg != NULL);
+
+	soup_session_send_and_read_async (user->priv->soup_session,
+					  msg,
+					  G_PRIORITY_DEFAULT,
+					  NULL,
+					  (GAsyncReadyCallback) loved_tracks_response_cb,
+					  user);
 }
 
 static void
 loved_tracks_response_cb (SoupSession *session,
-                          SoupMessage *msg,
-                          gpointer user_data)
+                          GAsyncResult *result,
+                          RBAudioscrobblerUser *user)
 {
-	RBAudioscrobblerUser *user;
+	GBytes *bytes;
+	const char *body;
 	GPtrArray *loved_tracks;
 
-	user = RB_AUDIOSCROBBLER_USER (user_data);
-	loved_tracks = parse_loved_tracks (user, msg->response_body->data);
+	bytes = soup_session_send_and_read_finish (session, result, NULL);
+	if (bytes != NULL) {
+		body = g_bytes_get_data (bytes, NULL);
+		loved_tracks = parse_loved_tracks (user, body);
 
-	if (loved_tracks != NULL) {
-		rb_debug ("loved tracks request was successful");
+		if (loved_tracks != NULL) {
+			rb_debug ("loved tracks request was successful");
 
-		if (user->priv->loved_tracks != NULL) {
-			g_ptr_array_unref (user->priv->loved_tracks);
+			if (user->priv->loved_tracks != NULL) {
+				g_ptr_array_unref (user->priv->loved_tracks);
+			}
+			user->priv->loved_tracks = loved_tracks;
+
+			save_response_to_cache (user, "loved_tracks", body);
+
+			g_signal_emit (user, rb_audioscrobbler_user_signals[LOVED_TRACKS_UPDATED],
+				       0, user->priv->loved_tracks);
+		} else {
+			rb_debug ("invalid response from loved tracks request");
 		}
-		user->priv->loved_tracks = loved_tracks;
 
-		save_response_to_cache (user, "loved_tracks", msg->response_body->data);
-
-		g_signal_emit (user, rb_audioscrobbler_user_signals[LOVED_TRACKS_UPDATED],
-		               0, user->priv->loved_tracks);
+		g_bytes_unref (bytes);
 	} else {
-		rb_debug ("invalid response from loved tracks request");
+		rb_debug ("error sending loved tracks request");
 	}
 }
 
@@ -1281,51 +1313,68 @@ load_cached_top_artists (RBAudioscrobblerUser *user)
 static void
 request_top_artists (RBAudioscrobblerUser *user, int limit)
 {
-	char *msg_url;
+	const char *api_key;
+	const char *api_url;
+	char *limit_str;
+	char *query;
 	SoupMessage *msg;
 
 	rb_debug ("requesting top artists");
 
-	msg_url = g_strdup_printf ("%s?method=library.getArtists&user=%s&api_key=%s&limit=%i&format=json",
-	                           rb_audioscrobbler_service_get_api_url (user->priv->service),
-	                           user->priv->username,
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
-	                           limit);
+	api_url = rb_audioscrobbler_service_get_api_url (user->priv->service);
+	api_key = rb_audioscrobbler_service_get_api_key (user->priv->service);
 
-	msg = soup_message_new ("GET", msg_url);
-	soup_session_queue_message (user->priv->soup_session,
-	                            msg,
-	                            top_artists_response_cb,
-	                            user);
+	limit_str = g_strdup_printf ("%d", limit);
+	query = soup_form_encode ("method", "library.getArtists",
+				  "user", user->priv->username,
+				  "api_key", api_key,
+				  "limit", limit_str,
+				  "format", "json",
+				  NULL);
+	g_free (limit_str);
 
-	g_free (msg_url);
+	msg = soup_message_new_from_encoded_form (SOUP_METHOD_GET, api_url, query);
+	g_return_if_fail (msg != NULL);
+
+	soup_session_send_and_read_async (user->priv->soup_session,
+					  msg,
+					  G_PRIORITY_DEFAULT,
+					  NULL,
+					  (GAsyncReadyCallback) top_artists_response_cb,
+					  user);
 }
 
 static void
 top_artists_response_cb (SoupSession *session,
-                         SoupMessage *msg,
-                         gpointer user_data)
+                         GAsyncResult *result,
+			 RBAudioscrobblerUser *user)
 {
-	RBAudioscrobblerUser *user;
+	GBytes *bytes;
+	const char *body;
 	GPtrArray *top_artists;
 
-	user = RB_AUDIOSCROBBLER_USER (user_data);
-	top_artists = parse_top_artists (user, msg->response_body->data);
+	bytes = soup_session_send_and_read_finish (session, result, NULL);
+	if (bytes != NULL) {
+		body = g_bytes_get_data (bytes, NULL);
+		top_artists = parse_top_artists (user, body);
 
-	if (top_artists != NULL) {
-		rb_debug ("top artists request was successful");
+		if (top_artists != NULL) {
+			rb_debug ("top artists request was successful");
 
-		if (user->priv->top_artists != NULL) {
-			g_ptr_array_unref (user->priv->top_artists);
+			if (user->priv->top_artists != NULL) {
+				g_ptr_array_unref (user->priv->top_artists);
+			}
+			user->priv->top_artists = top_artists;
+
+			save_response_to_cache (user, "top_artists", body);
+
+			g_signal_emit (user, rb_audioscrobbler_user_signals[TOP_ARTISTS_UPDATED],
+				       0, user->priv->top_artists);
+		} else {
+			rb_debug ("invalid response from top artists request");
 		}
-		user->priv->top_artists = top_artists;
-
-		save_response_to_cache (user, "top_artists", msg->response_body->data);
-
-		g_signal_emit (user, rb_audioscrobbler_user_signals[TOP_ARTISTS_UPDATED],
-		               0, user->priv->top_artists);
 	} else {
-		rb_debug ("invalid response from top artists request");
+		rb_debug ("error sending top artists request");
 	}
 }
 
@@ -1342,9 +1391,9 @@ parse_top_artists (RBAudioscrobblerUser *user, const char *data)
 		JsonObject *root_object;
 		root_object = json_node_get_object (json_parser_get_root (parser));
 
-		if (json_object_has_member (root_object, "artists")) {
+		if (json_object_has_member (root_object, "topartists")) {
 			JsonObject *top_artists_object;
-			top_artists_object = json_object_get_object_member (root_object, "artists");
+			top_artists_object = json_object_get_object_member (root_object, "topartists");
 
 			if (json_object_has_member (top_artists_object, "artist") == TRUE) {
 				JsonArray *artist_array;
@@ -1353,7 +1402,7 @@ parse_top_artists (RBAudioscrobblerUser *user, const char *data)
 				top_artists = parse_artist_array (user, artist_array);
 			}
 		} else {
-			rb_debug ("error parsing top artists response: no artists object exists");
+			rb_debug ("error parsing top artists response: no topartists object exists");
 		}
 	} else {
 		rb_debug ("error parsing top artists response: empty or invalid response");
@@ -1364,134 +1413,6 @@ parse_top_artists (RBAudioscrobblerUser *user, const char *data)
 	return top_artists;
 }
 
-/* recommended artists */
-static void
-load_cached_recommended_artists (RBAudioscrobblerUser *user)
-{
-	char *filename;
-	char *data;
-
-	filename = calculate_cached_response_path (user, "recommended_artists");
-
-	/* delete old data */
-	if (user->priv->recommended_artists != NULL) {
-		g_ptr_array_unref (user->priv->recommended_artists);
-		user->priv->recommended_artists = NULL;
-	}
-
-	/* load cached data if it exists */
-	if (g_file_get_contents (filename, &data, NULL, NULL) == TRUE) {
-		rb_debug ("loading cached recommended artists");
-		user->priv->recommended_artists = parse_recommended_artists (user, data);
-	}
-
-	/* emit updated signal */
-	g_signal_emit (user, rb_audioscrobbler_user_signals[RECOMMENDED_ARTISTS_UPDATED],
-	               0, user->priv->recommended_artists);
-
-	g_free (filename);
-	g_free (data);
-}
-
-static void
-request_recommended_artists (RBAudioscrobblerUser *user, int limit)
-{
-	char *sig_arg;
-	char *sig;
-	char *msg_url;
-	SoupMessage *msg;
-
-	rb_debug ("requesting recommended artists");
-
-	sig_arg = g_strdup_printf ("api_key%slimit%imethoduser.getRecommendedArtistssk%s%s",
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
-	                           limit,
-	                           user->priv->session_key,
-	                           rb_audioscrobbler_service_get_api_secret (user->priv->service));
-	sig = g_compute_checksum_for_string (G_CHECKSUM_MD5, sig_arg, -1);
-
-	msg_url = g_strdup_printf ("%s?method=user.getRecommendedArtists&api_key=%s&api_sig=%s&sk=%s&limit=%i&format=json",
-	                           rb_audioscrobbler_service_get_api_url (user->priv->service),
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
-	                           sig,
-	                           user->priv->session_key,
-	                           limit);
-
-	msg = soup_message_new ("GET", msg_url);
-	soup_session_queue_message (user->priv->soup_session,
-	                            msg,
-	                            recommended_artists_response_cb,
-	                            user);
-
-	g_free (sig_arg);
-	g_free (sig);
-	g_free (msg_url);
-}
-
-static void
-recommended_artists_response_cb (SoupSession *session,
-                                 SoupMessage *msg,
-                                 gpointer user_data)
-{
-	RBAudioscrobblerUser *user;
-	GPtrArray *recommended_artists;
-
-	user = RB_AUDIOSCROBBLER_USER (user_data);
-	recommended_artists = parse_recommended_artists (user, msg->response_body->data);
-
-	if (recommended_artists != NULL) {
-		rb_debug ("recommended artists request was successful");
-
-		if (user->priv->recommended_artists != NULL) {
-			g_ptr_array_unref (user->priv->recommended_artists);
-		}
-		user->priv->recommended_artists = recommended_artists;
-
-		save_response_to_cache (user, "recommended_artists", msg->response_body->data);
-
-		g_signal_emit (user, rb_audioscrobbler_user_signals[RECOMMENDED_ARTISTS_UPDATED],
-		               0, user->priv->recommended_artists);
-	} else {
-		rb_debug ("invalid response from recommended artists request");
-	}
-}
-
-static GPtrArray *
-parse_recommended_artists (RBAudioscrobblerUser *user, const char *data)
-{
-	GPtrArray *recommended_artists;
-	JsonParser *parser;
-
-	recommended_artists = NULL;
-
-	parser = json_parser_new ();
-	if (data != NULL && json_parser_load_from_data (parser, data, -1, NULL)) {
-		JsonObject *root_object;
-		root_object = json_node_get_object (json_parser_get_root (parser));
-
-		if (json_object_has_member (root_object, "recommendations")) {
-			JsonObject *recommended_artists_object;
-			recommended_artists_object = json_object_get_object_member (root_object, "recommendations");
-
-			if (json_object_has_member (recommended_artists_object, "artist") == TRUE) {
-				JsonArray *artist_array;
-
-				artist_array = json_object_get_array_member (recommended_artists_object, "artist");
-				recommended_artists = parse_artist_array (user, artist_array);
-			}
-		} else {
-			rb_debug ("error parsing recommended artists response: no recommendations object exists");
-			rb_debug ("probably due to authentication error");
-		}
-	} else {
-		rb_debug ("error parsing recommended artists response: empty or invalid response");
-	}
-
-	g_object_unref (parser);
-
-	return recommended_artists;
-}
-
 static char *
 calculate_cached_image_path (RBAudioscrobblerUser *user, RBAudioscrobblerUserData *data)
 {
@@ -1717,14 +1638,6 @@ image_download_cb (GObject *source_object, GAsyncResult *res, gpointer user_data
 						}
 					}
 				}
-				if (user->priv->recommended_artists != NULL) {
-					for (i = 0; i < user->priv->recommended_artists->len; i++) {
-						if (g_ptr_array_index (user->priv->recommended_artists, i) == data) {
-							g_signal_emit (user, rb_audioscrobbler_user_signals[RECOMMENDED_ARTISTS_UPDATED],
-							               0, user->priv->recommended_artists);
-						}
-					}
-				}
 			}
 		}
 		g_free (dest_file_path);
@@ -1741,56 +1654,55 @@ rb_audioscrobbler_user_love_track (RBAudioscrobblerUser *user,
                                    const char *title,
                                    const char *artist)
 {
+	const char *api_key;
+	const char *api_sec;
+	const char *api_url;
 	char *sig_arg;
 	char *sig;
-	char *escaped_title;
-	char *escaped_artist;
-	char *request;
+	char *query;
 	SoupMessage *msg;
 
 	rb_debug ("loving track %s - %s", artist, title);
 
+	api_key = rb_audioscrobbler_service_get_api_key (user->priv->service);
+	api_sec = rb_audioscrobbler_service_get_api_secret (user->priv->service);
+	api_url = rb_audioscrobbler_service_get_api_url (user->priv->service);
+
 	sig_arg = g_strdup_printf ("api_key%sartist%smethodtrack.lovesk%strack%s%s",
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
+	                           api_key,
 	                           artist,
 	                           user->priv->session_key,
 	                           title,
-	                           rb_audioscrobbler_service_get_api_secret (user->priv->service));
+				   api_sec);
 
 	sig = g_compute_checksum_for_string (G_CHECKSUM_MD5, sig_arg, -1);
 
-	escaped_title = g_uri_escape_string (title, NULL, FALSE);
-	escaped_artist = g_uri_escape_string (artist, NULL, FALSE);
-
-	request = g_strdup_printf ("method=track.love&track=%s&artist=%s&api_key=%s&api_sig=%s&sk=%s",
-	                           escaped_title,
-	                           escaped_artist,
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
-	                           sig,
-	                           user->priv->session_key);
-
-	msg = soup_message_new ("POST", rb_audioscrobbler_service_get_api_url (user->priv->service));
-	soup_message_set_request (msg,
-	                          "application/x-www-form-urlencoded",
-	                          SOUP_MEMORY_COPY,
-	                          request,
-	                          strlen (request));
-	soup_session_queue_message (user->priv->soup_session,
-	                            msg,
-	                            love_track_response_cb,
-	                            user);
+	query = soup_form_encode ("method", "track.love",
+				  "track", title,
+				  "artist", artist,
+				  "api_key", api_key,
+				  "api_sig", sig,
+				  "sk", user->priv->session_key,
+				  NULL);
 
 	g_free (sig_arg);
 	g_free (sig);
-	g_free (escaped_title);
-	g_free (escaped_artist);
-	g_free (request);
+
+	msg = soup_message_new_from_encoded_form (SOUP_METHOD_POST, api_url, query);
+	g_return_if_fail (msg != NULL);
+
+	soup_session_send_and_read_async (user->priv->soup_session,
+					  msg,
+					  G_PRIORITY_DEFAULT,
+					  NULL,
+					  (GAsyncReadyCallback) love_track_response_cb,
+					  user);
 }
 
 static void
 love_track_response_cb (SoupSession *session,
-                        SoupMessage *msg,
-                        gpointer user_data)
+                        GAsyncResult *result,
+                        RBAudioscrobblerUser *user)
 {
 	/* Don't know if there's anything to do here,
 	 * might want a debug message indicating success or failure?
@@ -1802,56 +1714,55 @@ rb_audioscrobbler_user_ban_track (RBAudioscrobblerUser *user,
                                   const char *title,
                                   const char *artist)
 {
+	const char *api_key;
+	const char *api_sec;
+	const char *api_url;
 	char *sig_arg;
 	char *sig;
-	char *escaped_title;
-	char *escaped_artist;
-	char *request;
+	char *query;
 	SoupMessage *msg;
 
 	rb_debug ("banning track %s - %s", artist, title);
 
-	sig_arg = g_strdup_printf ("api_key%sartist%smethodtrack.bansk%strack%s%s",
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
+	api_key = rb_audioscrobbler_service_get_api_key (user->priv->service);
+	api_sec = rb_audioscrobbler_service_get_api_secret (user->priv->service);
+	api_url = rb_audioscrobbler_service_get_api_url (user->priv->service);
+
+	sig_arg = g_strdup_printf ("api_key%sartist%smethodtrack.ban%strack%s%s",
+	                           api_key,
 	                           artist,
 	                           user->priv->session_key,
 	                           title,
-	                           rb_audioscrobbler_service_get_api_secret (user->priv->service));
+				   api_sec);
 
 	sig = g_compute_checksum_for_string (G_CHECKSUM_MD5, sig_arg, -1);
 
-	escaped_title = g_uri_escape_string (title, NULL, FALSE);
-	escaped_artist = g_uri_escape_string (artist, NULL, FALSE);
-
-	request = g_strdup_printf ("method=track.ban&track=%s&artist=%s&api_key=%s&api_sig=%s&sk=%s",
-	                           escaped_title,
-	                           escaped_artist,
-	                           rb_audioscrobbler_service_get_api_key (user->priv->service),
-	                           sig,
-	                           user->priv->session_key);
-
-	msg = soup_message_new ("POST", rb_audioscrobbler_service_get_api_url (user->priv->service));
-	soup_message_set_request (msg,
-	                          "application/x-www-form-urlencoded",
-	                          SOUP_MEMORY_COPY,
-	                          request,
-	                          strlen (request));
-	soup_session_queue_message (user->priv->soup_session,
-	                            msg,
-	                            ban_track_response_cb,
-	                            user);
+	query = soup_form_encode ("method", "track.ban",
+				  "track", title,
+				  "artist", artist,
+				  "api_key", api_key,
+				  "api_sig", sig,
+				  "sk", user->priv->session_key,
+				  NULL);
 
 	g_free (sig_arg);
 	g_free (sig);
-	g_free (escaped_title);
-	g_free (escaped_artist);
-	g_free (request);
+
+	msg = soup_message_new_from_encoded_form (SOUP_METHOD_POST, api_url, query);
+	g_return_if_fail (msg != NULL);
+
+	soup_session_send_and_read_async (user->priv->soup_session,
+					  msg,
+					  G_PRIORITY_DEFAULT,
+					  NULL,
+					  (GAsyncReadyCallback) ban_track_response_cb,
+					  user);
 }
 
 static void
 ban_track_response_cb (SoupSession *session,
-                       SoupMessage *msg,
-                       gpointer user_data)
+                       GAsyncResult *result,
+                       RBAudioscrobblerUser *user)
 {
 	/* Don't know if there's anything to do here,
 	 * might want a debug message indicating success or failure?
