@@ -48,7 +48,7 @@ magnatune_partner_id = "rhythmbox"
 # URIs
 magnatune_song_info_uri = "http://magnatune.com/info/song_info_xml.zip"
 magnatune_changed_uri = "http://magnatune.com/info/changed.txt"
-magnatune_buy_album_uri = "https://magnatune.com/buy/choose?"
+magnatune_member_signup_uri = "http://magnatune.com/member/signup?"
 magnatune_api_download_uri = "http://%s:%s@download.magnatune.com/buy/membership_free_dl_xml?"
 
 magnatune_in_progress_dir = Gio.file_new_for_path(RB.user_data_dir()).resolve_relative_path('magnatune')
@@ -65,7 +65,7 @@ class MagnatuneSource(RB.BrowserSource):
 		self.hate = self
 
 		self.__popup = None
-		self.__settings = Gio.Settings("org.gnome.rhythmbox.plugins.magnatune")
+		self.__settings = Gio.Settings.new("org.gnome.rhythmbox.plugins.magnatune")
 		# source state
 		self.__activated = False
 		self.__db = None
@@ -157,36 +157,34 @@ class MagnatuneSource(RB.BrowserSource):
 	def display_artist_info(self):
 		screen = self.props.shell.props.window.get_screen()
 		tracks = self.get_entry_view().get_selected_entries()
-		urls = set([])
+		if len(tracks) == 0:
+			return
+
+		tr = tracks[0]
+		sku = self.__sku_dict[tr.get_string(RB.RhythmDBPropType.LOCATION)]
+		url = self.__home_dict[sku]
+		Gtk.show_uri(screen, url, Gdk.CURRENT_TIME)
 
-		for tr in tracks:
-			sku = self.__sku_dict[tr.get_string(RB.RhythmDBPropType.LOCATION)]
-			url = self.__home_dict[sku]
-			if url not in urls:
-				Gtk.show_uri(screen, url, Gdk.CURRENT_TIME)
-				urls.add(url)
 
 	def download_redirect(self):
 		screen = self.props.shell.props.window.get_screen()
 		tracks = self.get_entry_view().get_selected_entries()
-		urls = set([])
+		if len(tracks) == 0:
+			return
+
+		url = magnatune_member_signup_uri + urllib.parse.urlencode({ 'ref': magnatune_partner_id })
+		Gtk.show_uri(screen, url, Gdk.CURRENT_TIME)
 
-		for tr in tracks:
-			sku = self.__sku_dict[tr.get_string(RB.RhythmDBPropType.LOCATION)]
-			url = magnatune_buy_album_uri + urllib.parse.urlencode({ 'sku': sku, 'ref': magnatune_partner_id })
-			if url not in urls:
-				Gtk.show_uri(screen, url, Gdk.CURRENT_TIME)
-				urls.add(url)
 
 	def download_album(self):
 		if self.__settings['account-type'] != 'download':
-			# The user doesn't have a download account, so redirect them to the download signup page
+			# The user doesn't have a download account, so redirect them to the member signup page
 			self.download_redirect()
 			return
 
 		try:
 			# Just use the first library location
-			library = Gio.Settings("org.gnome.rhythmbox.rhythmdb")
+			library = Gio.Settings.new("org.gnome.rhythmbox.rhythmdb")
 			library_location = library['locations'][0]
 		except IndexError as e:
 			RB.error_dialog(title = _("Couldn't download album"),
@@ -426,9 +424,13 @@ class MagnatuneSource(RB.BrowserSource):
 
 	def __download_album(self, audio_dl_uri, sku):
 		def update_progress(self):
-			complete, total = map(sum, zip(*self.__downloads.values()))
-			if total > 0:
-				self.__download_progress.props.task_progress = min(float(complete) / total, 1.0)
+			if len(self.__downloads) == 0:
+				self.__download_progress.props.task_outcome = RB.TaskOutcome.COMPLETE
+				self.__download_progress = None
+			else:
+				complete, total = map(sum, zip(*self.__downloads.values()))
+				if total > 0:
+					self.__download_progress.props.task_progress = min(float(complete) / total, 1.0)
 
 		def download_progress(copy, complete, total, self):
 			self.__downloads[audio_dl_uri] = (complete, total)
@@ -437,7 +439,6 @@ class MagnatuneSource(RB.BrowserSource):
 		def download_finished(copy, success, self):
 			del self.__downloads[audio_dl_uri]
 			del self.__copies[audio_dl_uri]
-			update_progress(self)
 
 			print("download of %s finished: %s" % (audio_dl_uri, success))
 			if success:
@@ -445,14 +446,12 @@ class MagnatuneSource(RB.BrowserSource):
 			else:
 				remove_download_files()
 
-			if len(self.__downloads) == 0:
-				self.__download_progress.props.task_outcome = RB.TaskOutcome.COMPLETE
-				self.__download_progress = None
+			update_progress(self)
 
 
 		def unzip_album():
 			# just use the first library location
-			library = Gio.Settings("org.gnome.rhythmbox.rhythmdb")
+			library = Gio.Settings.new("org.gnome.rhythmbox.rhythmdb")
 			library_location = Gio.file_new_for_uri(library['locations'][0])
 
 			print("unzipping %s" % dest.get_path())
@@ -464,7 +463,7 @@ class MagnatuneSource(RB.BrowserSource):
 				track_uri = RB.sanitize_uri_for_filesystem(track_uri)
 				RB.uri_create_parent_dirs(track_uri)
 
-				track_out = Gio.file_new_for_uri(track_uri).create(Gio.FileCreateFlags.NONE, None)
+				track_out = Gio.file_new_for_uri(track_uri).replace(None, False, Gio.FileCreateFlags.NONE, None)
 				if track_out is not None:
 					track_out.write(album.read(track), None)
 					track_out.close(None)
@@ -488,22 +487,19 @@ class MagnatuneSource(RB.BrowserSource):
 					     Gio.FileCreateFlags.PRIVATE|Gio.FileCreateFlags.REPLACE_DESTINATION,
 					     None)
 
-		try:
-			# For some reason, Gio.FileCopyFlags.OVERWRITE doesn't work for copy_async
-			dest.delete(None)
-		except:
-			pass
-
 		if self.__download_progress is None:
 			self.__download_progress = RB.TaskProgressSimple.new()
 			self.__download_progress.props.task_label = _("Downloading from Magnatune")
-			self.__download_progress.connect('cancel', self.cancel_downloads)
+			self.__download_progress.connect('cancel-task', self.cancel_downloads)
+			self.props.shell.props.task_list.add_task(self.__download_progress)
 
-		dl = RB.AsyncCopy()
-		dl.set_progress(download_progress, self)
-		dl.start(audio_dl_uri, dest.get_uri(), download_finished, self)
-		self.__downloads[audio_dl_uri] = (0, 0) # (current, total)
-		self.__copies[audio_dl_uri] = dl
+		# one async copy object per download
+		if audio_dl_uri not in self.__copies:
+			dl = RB.AsyncCopy()
+			dl.set_progress(download_progress, self)
+			dl.start(audio_dl_uri, dest.get_uri(), download_finished, self)
+			self.__downloads[audio_dl_uri] = (0, 0) # (current, total)
+			self.__copies[audio_dl_uri] = dl
 
 	def cancel_downloads(self, task):
 		for download in self.__copies.values():
@@ -514,12 +510,12 @@ class MagnatuneSource(RB.BrowserSource):
 	def playing_entry_changed(self, entry):
 		if not self.__db or not entry:
 			return
-		if entry.get_entry_type() != self.__db.entry_type_get_by_name("MagnatuneEntryType"):
+		if entry.get_entry_type() != self.__db.entry_type_get_by_name("magnatune"):
 			return
 
 		sku = self.__sku_dict[entry.get_string(RB.RhythmDBPropType.LOCATION)]
 		key = RB.ExtDBKey.create_storage("album", entry.get_string(RB.RhythmDBPropType.ALBUM))
 		key.add_field("artist", entry.get_string(RB.RhythmDBPropType.ARTIST))
-		self.__art_store.store_uri(key, self.__art_dict[sku])
+		self.__art_store.store_uri(key, RB.ExtDBSourceType.EMBEDDED, self.__art_dict[sku])
 
 GObject.type_register(MagnatuneSource)
