@@ -59,6 +59,7 @@ struct _RBNotificationPlugin
 
 	gchar *notify_art_path;
 	RBExtDBKey *notify_art_key;
+	gboolean is_flatpak;
 	NotifyNotification *notification;
 	NotifyNotification *misc_notification;
 	gboolean notify_supports_actions;
@@ -199,7 +200,7 @@ do_notify (RBNotificationPlugin *plugin,
 					      g_variant_new_string (image_uri));
 	}
 
-        if (playback)
+        if (!plugin->is_flatpak && playback)
         	notify_notification_set_category (notification, "x-gnome.music");
         notify_notification_set_hint (notification, "desktop-entry",
                                       g_variant_new_string ("org.gnome.Rhythmbox3"));
@@ -631,8 +632,10 @@ impl_deactivate	(PeasActivatable *bplugin)
 	g_signal_handlers_disconnect_by_func (shell, shell_notify_playing_cb, plugin);
 	g_signal_handlers_disconnect_by_func (shell, shell_notify_custom_cb, plugin);
 
-	g_object_unref (plugin->art_store);
-	plugin->art_store = NULL;
+	if (plugin->art_store) {
+		rb_ext_db_cancel_requests (plugin->art_store, (RBExtDBRequestCallback) art_cb, plugin);
+		g_clear_object (&plugin->art_store);
+	}
 
 	/* forget what's playing */
 	if (plugin->notify_art_key)
@@ -649,8 +652,12 @@ impl_deactivate	(PeasActivatable *bplugin)
 }
 
 static void
-rb_notification_plugin_init (RBNotificationPlugin *plugin)
+rb_notification_plugin_init (RBNotificationPlugin *bplugin)
 {
+	RBNotificationPlugin *plugin;
+
+	plugin = RB_NOTIFICATION_PLUGIN (bplugin);
+	plugin->is_flatpak = g_file_test ("/.flatpak-info", G_FILE_TEST_EXISTS);
 }
 
 G_MODULE_EXPORT void
