@@ -36,6 +36,8 @@
 #include "rhythmdb-metadata-cache.h"
 #include "rhythmdb-private.h"
 
+#include <metadata/rb-ext-db-key.h>
+
 #include "rb-util.h"
 
 
@@ -71,7 +73,7 @@ struct _RhythmDBEntryTypePrivate
 G_DEFINE_TYPE (RhythmDBEntryType, rhythmdb_entry_type, G_TYPE_OBJECT)
 
 /**
- * SECTION:rhythmdb-entry-type
+ * SECTION:rhythmdbentrytype
  * @short_description: Database entry type base class
  *
  * This is the base class for database entry type classes, which provide
@@ -350,6 +352,77 @@ rhythmdb_entry_type_purge_metadata_cache (RhythmDBEntryType *etype, const char *
 				       NULL);
 }
 
+/**
+ * rhythmdb_entry_create_ext_db_key:
+ * @entry: a #RhythmDBEntry
+ * @prop: the primary #RhythmDBPropType for metadata lookups
+ *
+ * Creates a #RBExtDBKey for finding external metadata
+ * for a given property.  This is mostly useful for finding album or
+ * track related data.
+ *
+ * Return value: the new #RBExtDBKey
+ */
+RBExtDBKey *
+rhythmdb_entry_create_ext_db_key (RhythmDBEntry *entry, RhythmDBPropType prop)
+{
+	RhythmDBEntryType *etype = rhythmdb_entry_get_entry_type (entry);
+	RhythmDBEntryTypeClass *klass = RHYTHMDB_ENTRY_TYPE_GET_CLASS (etype);
+	RBExtDBKey *key;
+	const char *str;
+
+
+	if (klass->create_ext_db_key)
+		return klass->create_ext_db_key (etype, entry, prop);
+
+	switch (prop) {
+	case RHYTHMDB_PROP_ALBUM:
+		str = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM);
+		if (g_strcmp0 (str, "") != 0 && g_strcmp0 (str, _("Unknown")) != 0) {
+			key = rb_ext_db_key_create_lookup ("album", str);
+			rb_ext_db_key_add_field (key,
+						 "artist",
+						 rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST));
+			str = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM_ARTIST);
+			if (g_strcmp0 (str, "") != 0 && g_strcmp0 (str, _("Unknown")) != 0) {
+				rb_ext_db_key_add_field (key, "artist", str);
+			}
+
+			str = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_MUSICBRAINZ_ALBUMID);
+			if (g_strcmp0 (str, "") != 0 && g_strcmp0 (str, _("Unknown")) != 0) {
+				rb_ext_db_key_add_info (key, "musicbrainz-albumid", str);
+			}
+			break;
+		}
+		/* fall through if there's no album information */
+
+	case RHYTHMDB_PROP_TITLE:
+		key = rb_ext_db_key_create_lookup ("title", rhythmdb_entry_get_string (entry, prop));
+		/* maybe these should be info? */
+		str = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ARTIST);
+		if (g_strcmp0 (str, "") != 0 && g_strcmp0 (str, _("Unknown")) != 0) {
+			rb_ext_db_key_add_field (key, "artist", str);
+		}
+		str = rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_ALBUM);
+		if (g_strcmp0 (str, "") != 0 && g_strcmp0 (str, _("Unknown")) != 0) {
+			rb_ext_db_key_add_field (key, "album", str);
+		}
+		break;
+
+	case RHYTHMDB_PROP_ARTIST:
+		/* not really sure what this might be useful for */
+		key = rb_ext_db_key_create_lookup ("artist", rhythmdb_entry_get_string (entry, prop));
+		break;
+
+	default:
+		g_assert_not_reached ();
+	}
+
+	rb_ext_db_key_add_info (key, "location", rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_LOCATION));
+	return key;
+}
+
+
 static void
 rhythmdb_entry_type_init (RhythmDBEntryType *etype)
 {
