@@ -39,7 +39,7 @@
 #include <widgets/rb-dialog.h>
 
 /**
- * SECTION:rb-application
+ * SECTION:rbapplication
  * @short_description: the rhythmbox subclass of GtkApplication
  *
  * RBApplication contains some interactions with the desktop
@@ -200,7 +200,7 @@ about_action_cb (GSimpleAction *action, GVariant *parameters, gpointer user_data
 			       "copyright", "Copyright \xc2\xa9 2005 - 2019 The Rhythmbox authors\nCopyright \xc2\xa9 2003 - 2005 Colin Walters\nCopyright \xc2\xa9 2002, 2003 Jorn Baayen",
 			       "license", license_trans,
 			       "website-label", _("Rhythmbox Website"),
-			       "website", "https://wiki.gnome.org/Apps/Rhythmbox",
+			       "website", "https://gnome.pages.gitlab.gnome.org/rhythmbox/",
 			       "comments", comment->str,
 			       "authors", (const char **) authors,
 			       "documenters", (const char **) documenters,
