@@ -28,7 +28,7 @@
  */
 
 /**
- * SECTION:rb-shell-preferences
+ * SECTION:rbshellpreferences
  * @short_description: preferences dialog
  *
  * The preferences dialog is built around a #GtkNotebook widget, with two built-in
@@ -398,6 +398,7 @@ GtkWidget *
 rb_shell_preferences_new (GList *views)
 {
 	RBShellPreferences *shell_preferences;
+	GtkBuilder *builder;
 
 	shell_preferences = g_object_new (RB_TYPE_SHELL_PREFERENCES,
 				          NULL, NULL);
@@ -420,6 +421,13 @@ rb_shell_preferences_new (GList *views)
 		g_free (name);
 	}
 
+	/* make sure this goes last */
+	builder = rb_builder_load ("plugin-prefs.ui", NULL);
+	gtk_notebook_append_page (GTK_NOTEBOOK (shell_preferences->priv->notebook),
+				  GTK_WIDGET (gtk_builder_get_object (builder, "plugins_box")),
+				  gtk_label_new (_("Plugins")));
+	g_object_unref (builder);
+
 	return GTK_WIDGET (shell_preferences);
 }
 
