@@ -28,7 +28,7 @@
  */
 
 /**
- * SECTION:rb-shell
+ * SECTION:rbshell
  * @short_description: holds the Rhythmbox main window and everything else
  *
  * RBShell is the main application class in Rhythmbox.  It creates and holds
@@ -46,7 +46,16 @@
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
+
+#ifdef USE_GIREPOSITORY2
+#include <girepository/girepository.h>
+#define g_irepository_require_private	gi_repository_require_private
+#define g_irepository_require		gi_repository_require
+/* who cares about reference counts for a global singleton */
+#define g_irepository_get_default	gi_repository_dup_default
+#else
 #include <girepository.h>
+#endif
 
 #include <libpeas/peas.h>
 #include <libpeas-gtk/peas-gtk.h>
@@ -394,7 +403,7 @@ store_external_art_cb (RBExtDB *store, GValue *value, RBShell *shell)
 	char *data;
 	gsize data_size;
 	GError *error = NULL;
-	GString *s;
+	GBytes *b;
 	GValue *v;
 
 	if (G_VALUE_HOLDS (value, GDK_TYPE_PIXBUF) == FALSE) {
@@ -424,13 +433,10 @@ store_external_art_cb (RBExtDB *store, GValue *value, RBShell *shell)
 		return NULL;
 	}
 
-	s = g_slice_new0 (GString);
-	s->str = data;
-	s->len = data_size;
-	s->allocated_len = data_size;
+	b = g_bytes_new_take (data, data_size);
 	v = g_new0 (GValue, 1);
-	g_value_init (v, G_TYPE_GSTRING);
-	g_value_take_boxed (v, s);
+	g_value_init (v, G_TYPE_BYTES);
+	g_value_take_boxed (v, b);
 	return v;
 }
 
@@ -719,15 +725,6 @@ construct_load_ui (RBShell *shell)
 
 	shell->priv->play_button = GTK_WIDGET (gtk_builder_get_object (builder, "play-button"));
 
-	image = gtk_button_get_image (GTK_BUTTON (gtk_builder_get_object (builder, "next-button")));
-	gtk_image_set_from_icon_name (GTK_IMAGE (image), "media-skip-forward-symbolic", GTK_ICON_SIZE_LARGE_TOOLBAR);
-
-	image = gtk_button_get_image (GTK_BUTTON (gtk_builder_get_object (builder, "previous-button")));
-	gtk_image_set_from_icon_name (GTK_IMAGE (image), "media-skip-backward-symbolic", GTK_ICON_SIZE_LARGE_TOOLBAR);
-
-	image = gtk_button_get_image (GTK_BUTTON (gtk_builder_get_object (builder, "play-button")));
-	gtk_image_set_from_icon_name (GTK_IMAGE (image), "media-playback-start-symbolic", GTK_ICON_SIZE_LARGE_TOOLBAR);
-
 	/* this seems a bit unnecessary */
 	gtk_actionable_set_action_target_value (GTK_ACTIONABLE (gtk_builder_get_object (builder, "shuffle-button")),
 						g_variant_new_boolean (TRUE));
@@ -2250,7 +2247,7 @@ rb_shell_playing_changed_cb (RBShellPlayer *player, gboolean playing, RBShell *s
 
 	image = gtk_button_get_image (GTK_BUTTON (shell->priv->play_button));
 	if (playing) {
-		if (rb_source_can_pause (rb_shell_player_get_active_source (shell->priv->player_shell))) {
+		if (rb_source_can_pause (rb_shell_player_get_playing_source (shell->priv->player_shell))) {
 			icon_name = "media-playback-pause-symbolic";
 			tooltip = _("Pause playback");
 		} else {
@@ -2261,7 +2258,7 @@ rb_shell_playing_changed_cb (RBShellPlayer *player, gboolean playing, RBShell *s
 		icon_name = "media-playback-start-symbolic";
 		tooltip = _("Start playback");
 	}
-	gtk_image_set_from_icon_name (GTK_IMAGE (image), icon_name, GTK_ICON_SIZE_LARGE_TOOLBAR);
+	g_object_set (image, "icon-name", icon_name, NULL);
 
 	gtk_widget_set_tooltip_text (GTK_WIDGET (shell->priv->play_button), tooltip);
 }
