@@ -162,6 +162,9 @@ expire_task (RBTaskList *list, RBTaskProgress *task, gint seconds)
 	TaskExpiry *expiry;
 
 	cancel_expiry (list, task);
+	if (rb_list_model_find (list->model, task) == -1)
+		return;
+
 	expiry = g_new0 (TaskExpiry, 1);
 	expiry->task = task;
 	expiry->list = list;
@@ -207,7 +210,7 @@ rb_task_list_remove_task (RBTaskList *list, RBTaskProgress *task)
 }
 
 RBTaskList *
-rb_task_list_new ()
+rb_task_list_new (void)
 {
 	return RB_TASK_LIST (g_object_new (RB_TYPE_TASK_LIST, NULL));
 }
