@@ -58,7 +58,7 @@
 #include "rb-application.h"
 
 /**
- * SECTION:rb-playlist-source
+ * SECTION:rbplaylistsource
  * @short_description: Base class for playlist sources
  *
  * This class provides some common infrastructure for playlist
@@ -913,7 +913,7 @@ rb_playlist_source_entry_added_cb (RhythmDB *db,
 	location = rhythmdb_entry_get_refstring (entry, RHYTHMDB_PROP_LOCATION);
 
 	if (g_hash_table_lookup (source->priv->entries, location)) {
-		if (_rb_source_check_entry_type (RB_SOURCE (source), entry)) {
+		if (rb_source_check_entry_type (RB_SOURCE (source), entry)) {
 			rhythmdb_query_model_add_entry (source->priv->model, entry, -1);
 			source->priv->dirty = TRUE;
 		} else {
