@@ -28,7 +28,7 @@
  */
 
 /**
- * SECTION:rb-static-playlist-source
+ * SECTION:rbstaticplaylistsource
  * @short_description: Manually defined playlist class
  *
  * Static playlists are not defined by a query, but instead by manually selected
@@ -46,6 +46,7 @@
 
 #include <string.h>
 
+#include <libxml/entities.h>
 #include <libxml/tree.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -759,7 +760,7 @@ rb_static_playlist_source_add_location_internal (RBStaticPlaylistSource *source,
 	if (entry) {
 		RBStaticPlaylistSourcePrivate *priv = RB_STATIC_PLAYLIST_SOURCE_GET_PRIVATE (source);
 
-		if (_rb_source_check_entry_type (RB_SOURCE (source), entry)) {
+		if (rb_source_check_entry_type (RB_SOURCE (source), entry)) {
 			rhythmdb_entry_ref (entry);
 			rhythmdb_query_model_add_entry (priv->base_model, entry, index);
 			rhythmdb_entry_unref (entry);
@@ -968,7 +969,7 @@ rb_static_playlist_source_filter_entry_drop (RhythmDBQueryModel *model,
 					     RhythmDBEntry *entry, 
 					     RBStaticPlaylistSource *source)
 {
-	if (_rb_source_check_entry_type (RB_SOURCE (source), entry)) {
+	if (rb_source_check_entry_type (RB_SOURCE (source), entry)) {
 		rb_debug ("allowing drop of entry %s", rhythmdb_entry_get_string (entry, RHYTHMDB_PROP_LOCATION));
 		return TRUE;
 	}
