@@ -50,7 +50,7 @@
 #define LABEL_SELECT_PADDING	20
 
 /**
- * SECTION:rb-header
+ * SECTION:rbheader
  * @short_description: playback area widgetry
  *
  * The RBHeader widget displays information about the current playing track
@@ -96,6 +96,7 @@ static void rb_header_extra_metadata_cb (RhythmDB *db, RhythmDBEntry *entry, con
 static void rb_header_sync (RBHeader *header);
 static void rb_header_sync_time (RBHeader *header);
 
+static void art_cb (RBExtDBKey *key, RBExtDBKey *store_key, const char *filename, GValue *data, RBHeader *header);
 static void uri_dropped_cb (RBFadingImage *image, const char *uri, RBHeader *header);
 static void pixbuf_dropped_cb (RBFadingImage *image, GdkPixbuf *pixbuf, RBHeader *header);
 static void image_button_press_cb (GtkWidget *widget, GdkEvent *event, RBHeader *header);
@@ -398,10 +399,10 @@ rb_header_constructed (GObject *object)
 
 	/* image display */
 	header->priv->art_store = rb_ext_db_new ("album-art");
-	g_signal_connect (header->priv->art_store,
-			  "added",
-			  G_CALLBACK (art_added_cb),
-			  header);
+	g_signal_connect_object (header->priv->art_store,
+				 "added",
+				 G_CALLBACK (art_added_cb),
+				 header, 0);
 	header->priv->image = GTK_WIDGET (g_object_new (RB_TYPE_FADING_IMAGE,
 							"fallback", RB_STOCK_MISSING_ARTWORK,
 							NULL));
@@ -457,6 +458,7 @@ rb_header_dispose (GObject *object)
 	}
 
 	if (header->priv->art_store != NULL) {
+		rb_ext_db_cancel_requests (header->priv->art_store, (RBExtDBRequestCallback) art_cb, header);
 		g_object_unref (header->priv->art_store);
 		header->priv->art_store = NULL;
 	}
@@ -547,19 +549,20 @@ rb_header_playing_song_changed_cb (RBShellPlayer *player, RhythmDBEntry *entry,
 		header->priv->duration = rhythmdb_entry_get_ulong (header->priv->entry,
 								   RHYTHMDB_PROP_DURATION);
 
+		key = rhythmdb_entry_create_ext_db_key (entry, RHYTHMDB_PROP_ALBUM);
 		if (header->priv->art_key == NULL ||
-		    rhythmdb_entry_matches_ext_db_key (header->priv->db, entry, header->priv->art_key) == FALSE) {
+		    rhythmdb_entry_matches_ext_db_key (header->priv->db, entry, header->priv->art_key) == FALSE ||
+		    rb_ext_db_key_is_null_match (key, header->priv->art_key)) {
 			rb_fading_image_start (RB_FADING_IMAGE (header->priv->image), 2000);
-			key = rhythmdb_entry_create_ext_db_key (entry, RHYTHMDB_PROP_ALBUM);
 			rb_ext_db_request (header->priv->art_store,
 					   key,
 					   (RBExtDBRequestCallback) art_cb,
 					   g_object_ref (header),
 					   g_object_unref);
-			rb_ext_db_key_free (key);
 		} else {
 			rb_debug ("existing art matches new entry");
 		}
+		rb_ext_db_key_free (key);
 
 		header->priv->playing_source = rb_shell_player_get_playing_source (player);
 		header->priv->status_changed_id =
