@@ -74,7 +74,7 @@ G_DEFINE_TYPE (RBRating, rb_rating, GTK_TYPE_WIDGET)
 #define RB_RATING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), RB_TYPE_RATING, RBRatingPrivate))
 
 /**
- * SECTION:rb-rating
+ * SECTION:rbrating
  * @short_description: widget for displaying song ratings
  *
  * This widget displays a rating (0-5 stars) and allows the user to
@@ -202,15 +202,19 @@ rb_rating_class_init (RBRatingClass *klass)
 static void
 rb_rating_init (RBRating *rating)
 {
+	AtkObject *atk_obj;
+
 	rating->priv = RB_RATING_GET_PRIVATE (rating);
 
 	/* create the needed icons */
 	rating->priv->pixbufs = rb_rating_pixbufs_load ();
 	
-	rb_rating_set_accessible_name (GTK_WIDGET (rating), 0.0);
+	rb_rating_set_accessible_description (GTK_WIDGET (rating), 0.0);
 
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (rating)),
 				     GTK_STYLE_CLASS_ENTRY);
+	atk_obj = gtk_widget_get_accessible (GTK_WIDGET (rating));
+	atk_object_set_role (atk_obj, ATK_ROLE_RATING);
 }
 
 static void
@@ -258,7 +262,7 @@ rb_rating_set_rating (RBRating *rating, gdouble value)
 	rating->priv->rating = value;
 
 	/* update accessible object name */
-	rb_rating_set_accessible_name (GTK_WIDGET (rating), value);
+	rb_rating_set_accessible_description (GTK_WIDGET (rating), value);
 
 	gtk_widget_queue_draw (GTK_WIDGET (rating));
 }
@@ -290,7 +294,7 @@ rb_rating_set_property (GObject *object,
  * Return value: a new #RBRating widget.
  */
 RBRating *
-rb_rating_new ()
+rb_rating_new (void)
 {
 	RBRating *rating;
 
